summaryrefslogtreecommitdiff
path: root/gitdb/test/lib.py
diff options
context:
space:
mode:
authorSebastian Thiel <byronimo@gmail.com>2011-05-04 19:33:36 +0200
committerSebastian Thiel <byronimo@gmail.com>2011-05-04 19:33:36 +0200
commitd20dadfde5824dcabda351f75a6784d616b2fd23 (patch)
tree8b75a3bab4a76d57cacb53b5cb54f20e23951a3a /gitdb/test/lib.py
parente24994109f01bd315fd6a2aaecbbfcdd05bd0586 (diff)
downloadgitdb-d20dadfde5824dcabda351f75a6784d616b2fd23.tar.gz
First rename session, db/test_base.py works, but there is much more work to do
Diffstat (limited to 'gitdb/test/lib.py')
-rw-r--r--gitdb/test/lib.py13
1 files changed, 6 insertions, 7 deletions
diff --git a/gitdb/test/lib.py b/gitdb/test/lib.py
index cdadaa7..9224f5f 100644
--- a/gitdb/test/lib.py
+++ b/gitdb/test/lib.py
@@ -1,12 +1,10 @@
# Copyright (C) 2010, 2011 Sebastian Thiel (byronimo@gmail.com) and contributors
#
# This module is part of GitDB and is released under
# the New BSD License: http://www.opensource.org/licenses/bsd-license.php
"""Utilities used in ODB testing"""
-from gitdb import (
- OStream,
- GitDB
- )
+from gitdb import OStream
+from gitdb.db.py import PureGitDB
from gitdb.stream import (
Sha1Writer,
ZippedStoreShaWriter
@@ -72,7 +70,7 @@ def with_rw_repo(func):
shutil.copytree(src_dir, path)
target_gitdir = os.path.join(path, '.git')
assert os.path.isdir(target_gitdir)
- return func(self, GitDB(target_gitdir))
+ return func(self, PureGitDB(target_gitdir))
#END wrapper
wrapper.__name__ = func.__name__
return with_rw_directory(wrapper)
@@ -195,7 +193,8 @@ class DeriveTest(OStream):
class TestBase(unittest.TestCase):
"""Base class for all tests"""
- rorepo = GitDB(repo_dir())
+ # The non-database specific tests just provides a default pure git database
+ rorepo = PureGitDB(repo_dir())
#} END bases
@@ -1,12 +1,10 @@
# Copyright (C) 2010, 2011 Sebastian Thiel (byronimo@gmail.com) and contributors
#
-# This module is part of GitDB and is released under
+# This module is part of PureGitDB and is released under
# the New BSD License: http://www.opensource.org/licenses/bsd-license.php
"""Utilities used in ODB testing"""